summaryrefslogtreecommitdiffstats
path: root/kmplot
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-22 20:17:27 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-22 20:17:27 -0600
commit78f8b2d68bde64c6e656effef397080ddfa1048d (patch)
tree83166b4ada30661b704e9ba65346af0f6608f94d /kmplot
parentf2240fa06f8350fbbd6e6a4f23fe0c164768c6c1 (diff)
downloadtdeedu-78f8b2d68bde64c6e656effef397080ddfa1048d.tar.gz
tdeedu-78f8b2d68bde64c6e656effef397080ddfa1048d.zip
Rename KInstance and KAboutData to avoid conflicts with KDE4
Diffstat (limited to 'kmplot')
-rw-r--r--kmplot/kmplot/MainDlg.cpp12
-rw-r--r--kmplot/kmplot/MainDlg.h6
-rw-r--r--kmplot/kmplot/main.cpp4
3 files changed, 11 insertions, 11 deletions
diff --git a/kmplot/kmplot/MainDlg.h b/kmplot/kmplot/MainDlg.h
index 6611c740..9ab99ba2 100644
--- a/kmplot/kmplot/MainDlg.h
+++ b/kmplot/kmplot/MainDlg.h
@@ -224,11 +224,11 @@ public:
virtual KParts::Part* createPartObject( TQWidget *parentWidget, const char *widgetName,
TQObject *parent, const char *name,
const char *classname, const TQStringList &args );
- static KInstance* instance();
+ static TDEInstance* instance();
private:
- static KInstance* s_instance;
- static KAboutData* s_about;
+ static TDEInstance* s_instance;
+ static TDEAboutData* s_about;
};
class BrowserExtension : public KParts::BrowserExtension
diff --git a/kmplot/kmplot/main.cpp b/kmplot/kmplot/main.cpp
index 5db19c03..25549a79 100644
--- a/kmplot/kmplot/main.cpp
+++ b/kmplot/kmplot/main.cpp
@@ -52,10 +52,10 @@ static KCmdLineOptions options[] =
int main( int argc, char **argv )
{
- KAboutData aboutData(
+ TDEAboutData aboutData(
"kmplot",
I18N_NOOP( "KmPlot" ),
- KP_VERSION, description, KAboutData::License_GPL,
+ KP_VERSION, description, TDEAboutData::License_GPL,
"(c) 2000-2002, Klaus-Dieter Möller",
0,
"http://edu.kde.org/kmplot/" );
diff --git a/kmplot/kmplot/MainDlg.cpp b/kmplot/kmplot/MainDlg.cpp
index eb45c929..5d69f929 100644
--- a/kmplot/kmplot/MainDlg.cpp
+++ b/kmplot/kmplot/MainDlg.cpp
@@ -766,12 +766,12 @@ void MainDlg::resetZoom()
}
// It's usually safe to leave the factory code alone.. with the
// notable exception of the KAboutData data
#include <kaboutdata.h>
#include <klocale.h>
-KInstance* KmPlotPartFactory::s_instance = 0L;
-KAboutData* KmPlotPartFactory::s_about = 0L;
+TDEInstance* KmPlotPartFactory::s_instance = 0L;
+TDEAboutData* KmPlotPartFactory::s_about = 0L;
KmPlotPartFactory::KmPlotPartFactory()
: KParts::Factory()
@@ -795,12 +795,12 @@ KParts::Part* KmPlotPartFactory::createPartObject( TQWidget *parentWidget, const
return obj;
}
-KInstance* KmPlotPartFactory::instance()
+TDEInstance* KmPlotPartFactory::instance()
{
if( !s_instance )
{
- s_about = new KAboutData("kmplot",I18N_NOOP( "KmPlotPart" ), "1");
- s_instance = new KInstance(s_about);
+ s_about = new TDEAboutData("kmplot",I18N_NOOP( "KmPlotPart" ), "1");
+ s_instance = new TDEInstance(s_about);
}
return s_instance;
}
@@ -766,12 +766,12 @@ void MainDlg::resetZoom()
}
// It's usually safe to leave the factory code alone.. with the
-// notable exception of the KAboutData data
+// notable exception of the TDEAboutData data
#include <kaboutdata.h>
#include <klocale.h>